export interface WebSocketOptions<T extends WebSocket> {
    reconnectTimeoutMillis?: number;
    onOpen?: (ws: T) => (Promise<void> | void);
    onDisconnect?: (ws: T, wantsReconnect: boolean) => (Promise<void> | void);
}
export type WSFactory<T> = string | (() => T) | (() => Promise<T>);
export declare class RobustWebSocket<T extends WebSocket> {
    private urlOrFactory;
    readonly onmessage: (msg: MessageEvent) => unknown;
    private ws;
    private isOpen;
    private closedManually;
    private wantReconnect;
    private options;
    private pendingOnOpens;
    constructor(urlOrFactory: WSFactory<T>, onmessage: (msg: MessageEvent) => unknown, options?: WebSocketOptions<T>);
    private init;
    private _doOnOpen;
    private _doWhenOpen;
    /**
     * Send a message to the server. If the socket is not open, the message will be queued until the
     * connection is reestablished, at which point it will be sent in order.  It is still possible
     * that messages can be lost if the connection is broken in transit or right before.
     */
    send(msg: string | ArrayBufferLike | ArrayBufferView): void;
    close(code?: number, reason?: string): void;
    forceReconnect(): void;
}
interface MessageEventAsyncIterable<T> extends AsyncIterable<MessageEvent<T>>, AsyncIterator<MessageEvent<T>> {
    onMessage(msg: MessageEvent<T>): void;
    onDisconnect(_: unknown, wanted: boolean): void;
}
export declare function messageAsyncIterator<T>(): MessageEventAsyncIterable<T>;
export {};
